<?php
/**
 * Search Listings Template
 *
 * @package WP Pro Real Estate 3
 * @subpackage Template
 */

/**
* Query multiple taxonomies
**/

$taxonomies_to_search = array(
	'beds' => 'Bedrooms',
	'baths' => 'Bathrooms',
	'property_type' => 'Property Type',
	'status' => 'Status',
	'state' => 'State',
	'zipcode' => 'Zipcode',
	'city' => 'City',
	'additional_features' => 'Additional Features'
);                                                                       

$search_values = array();

foreach ($taxonomies_to_search as $t => $l) {
	$var_name = 'ct_'. $t;
	
	if (!empty($_GET[$var_name])) {  
		$search_values[$t] = utf8_encode($_GET[$var_name]);
	}                                                     
}                                                          
                                   
$search_values['post_type'] = 'listings';
$search_values['paged'] = (get_query_var('paged')) ? get_query_var('paged') : 1;
$search_values['showposts'] = 10;

$mode = 'search'; 
    
// Check Price From/To
if (!empty($_GET['ct_price_from']) && !empty($_GET['ct_price_to'])) {
	$ct_price_from = str_replace(',', '', $_GET['ct_price_from']);
	$ct_price_to = str_replace(',', '', $_GET['ct_price_to']);
	$search_values['meta_query'] = array(
		array(
			'key' => '_ct_price',
			'value' => array( $ct_price_from, $ct_price_to ),
			'type' => 'numeric',
			'compare' => 'BETWEEN'
		)
	);
}
else if (!empty($_GET['ct_price_from'])) {               
	$ct_price_from = str_replace(',', '', $_GET['ct_price_from']);
	$search_values['meta_query'] = array(
		array(
			'key' => '_ct_price',
			'value' => $ct_price_from,
			'type' => 'numeric',
			'compare' => '>='
		)
	);	
}
else if (!empty($_GET['ct_price_to'])) {               
	$ct_price_to = str_replace(',', '', $_GET['ct_price_to']);
	$search_values['meta_query'] = array(
		array(
			'key' => '_ct_price',
			'value' => $ct_price_to,
			'type' => 'numeric',
			'compare' => '<='
		)
	);	
}

// Check to see if reference number matches
if (!empty($_GET['ct_mls'])) {
	$ct_mls = $_GET['ct_mls'];
	$search_values['meta_query'] = array(
		array(
			'key' => '_ct_mls',
			'value' => $ct_mls,
			'type' => 'numeric',
			'compare' => '='
		)
	);	
}

global $wp_query;

// save the existing query
$existing_query_obj = $wp_query;

$wp_query = new WP_Query( $search_values ); 

unset($search_values['post_type']);
unset($search_values['paged']);
unset($search_values['showposts']);                                

/** Prepare the title string by looping through all
the values we're going to query and put them together */
$search_params = ''; 
$loop = 0;
foreach ($search_values as $t => $s) {                                     
	if ($loop == 1) { 
		$search_params .= ', '; 
	} else {
		$loop = 1;
	}                              
	
	$term = get_term_by('slug',$s,$t);
	$name = $term->name;   
	
	$search_params .= '<strong>'. $name .'</strong>';                                    
}

get_header(); ?>

    <header id="archive-header" class="sixteen columns marT20 clear">
		<h5><?php if($search_params !="") { echo __('Searching: ', 'contempo'); echo $search_params; } else { echo __('Searching all listings', 'contempo'); } ?></h5>
    </header>
    
    <div id="map-wrap" class="columns marT20">
		<?php search_results_map(); ?>
        <div id="map" class="toggle sixteen columns"></div>
        <a href="#" class="show-hide">Hide Map</a>
    </div>
    
    <div class="sidebar three columns left marT20">
        <?php if (function_exists('dynamic_sidebar') && dynamic_sidebar('Listings Search Left') ) :else: endif; ?>	
    </div>
	
    <div class="ten columns left marT20">
        
		<?php get_template_part( 'loop', 'listings' ); ?>  
		
		<?php
		
		// restore WP_Query object
		$wp_query = $existing_query_obj;
		
		?>
	
    </div>
    
    <div class="sidebar three columns left marT20">
		<?php if (function_exists('dynamic_sidebar') && dynamic_sidebar('Listings Search Right') ) :else: endif; ?>	
    </div>

<?php get_footer(); ?>